commit a1a5590b12e04cbe673746a06e5bce88387bbb3a
Author: Robert Haas <rhaas@postgresql.org>
Date:   Fri Oct 18 08:30:40 2013 -0400

    Remove support for Tru64 UNIX (aka OSF/1) and Alpha.
    
    The Alpha architecture provides much weaker memory ordering
    guarantees than any other platform commonly in use today.  Without
    access to an alpha machine, we're unable to verify that our code
    works correctly on this platform; and it seems more likely than not
    that there are already bugs.  Tru64 UNIX is an operating system for
    Alpha, so get rid of that as well; support for Tru64 ended in 201.

diff --git a/configure.in b/configure.in
index d2bab32..35e6852 100644
--- a/configure.in
+++ b/configure.in
@@ -65,7 +65,6 @@ dragonfly*) template=netbsd ;;
    mingw*) template=win32 ;;
   netbsd*) template=netbsd ;;
  openbsd*) template=openbsd ;;
-     osf*) template=osf ;;
      sco*) template=sco ;;
  solaris*) template=solaris ;;
    sysv5*) template=unixware ;;
diff --git a/doc/src/sgml/installation.sgml b/doc/src/sgml/installation.sgml
index 2bdb3f1..dc72a98 100644
--- a/doc/src/sgml/installation.sgml
+++ b/doc/src/sgml/installation.sgml
@@ -1640,8 +1640,7 @@ PostgreSQL, contrib and HTML documentation successfully made. Ready to install.
     <systemitem class="osname">HP-UX</>,
     <systemitem class="osname">Linux</>,
     <systemitem class="osname">NetBSD</>, <systemitem
-    class="osname">OpenBSD</>, <systemitem class="osname">Tru64
-    UNIX</> (formerly <systemitem class="osname">Digital UNIX</>), and
+    class="osname">OpenBSD</>, and
     <systemitem class="osname">Solaris</>.
    </para>
 
@@ -1952,7 +1951,7 @@ kill `cat /usr/local/pgsql/data/postmaster.pid`
   <para>
    In general, <productname>PostgreSQL</> can be expected to work on
    these CPU architectures: x86, x86_64, IA64, PowerPC,
-   PowerPC 64, S/390, S/390x, Sparc, Sparc 64, Alpha, ARM, MIPS, MIPSEL, M68K,
+   PowerPC 64, S/390, S/390x, Sparc, Sparc 64, ARM, MIPS, MIPSEL, M68K,
    and PA-RISC.  Code support exists for M32R and VAX, but these
    architectures are not known to have been tested recently.  It is often
    possible to build on an unsupported CPU type by configuring with
@@ -1962,7 +1961,7 @@ kill `cat /usr/local/pgsql/data/postmaster.pid`
   <para>
    <productname>PostgreSQL</> can be expected to work on these operating
    systems: Linux (all recent distributions), Windows (Win2000 SP4 and later),
-   FreeBSD, OpenBSD, NetBSD, Mac OS X, AIX, HP/UX, Solaris, Tru64 Unix,
+   FreeBSD, OpenBSD, NetBSD, Mac OS X, AIX, HP/UX, Solaris,
    and UnixWare.  Other Unix-like systems may also work but are not currently
    being tested.  In most cases, all CPU architectures supported by
    a given operating system will work.  Look in
diff --git a/src/backend/main/main.c b/src/backend/main/main.c
index d71885d..f37e06f 100644
--- a/src/backend/main/main.c
+++ b/src/backend/main/main.c
@@ -23,14 +23,6 @@
 #include <pwd.h>
 #include <unistd.h>
 
-#if defined(__alpha) && defined(__osf__)		/* no __alpha__ ? */
-#include <sys/sysinfo.h>
-#include "machine/hal_sysinfo.h"
-#define ASSEMBLER
-#include <sys/proc.h>
-#undef ASSEMBLER
-#endif
-
 #if defined(__NetBSD__)
 #include <sys/param.h>
 #endif
@@ -214,27 +206,6 @@ static void
 startup_hacks(const char *progname)
 {
 	/*
-	 * On some platforms, unaligned memory accesses result in a kernel trap;
-	 * the default kernel behavior is to emulate the memory access, but this
-	 * results in a significant performance penalty.  We want PG never to make
-	 * such unaligned memory accesses, so this code disables the kernel
-	 * emulation: unaligned accesses will result in SIGBUS instead.
-	 */
-#ifdef NOFIXADE
-
-#if defined(__alpha)			/* no __alpha__ ? */
-	{
-		int			buffer[] = {SSIN_UACPROC, UAC_SIGBUS | UAC_NOPRINT};
-
-		if (setsysinfo(SSI_NVPAIRS, buffer, 1, (caddr_t) NULL,
-					   (unsigned long) NULL) < 0)
-			write_stderr("%s: setsysinfo failed: %s\n",
-						 progname, strerror(errno));
-	}
-#endif   /* __alpha */
-#endif   /* NOFIXADE */
-
-	/*
 	 * Windows-specific execution environment hacking.
 	 */
 #ifdef WIN32
diff --git a/src/backend/port/dynloader/osf.c b/src/backend/port/dynloader/osf.c
deleted file mode 100644
index aabf805..0000000
--- a/src/backend/port/dynloader/osf.c
+++ /dev/null
@@ -1,7 +0,0 @@
-/*
- * src/backend/port/dynloader/osf.c
- *
- * Dummy file used for nothing at this point
- *
- * see osf.h
- */
diff --git a/src/backend/port/dynloader/osf.h b/src/backend/port/dynloader/osf.h
deleted file mode 100644
index 2866280..0000000
--- a/src/backend/port/dynloader/osf.h
+++ /dev/null
@@ -1,47 +0,0 @@
-/*-------------------------------------------------------------------------
- *
- * osf.h
- *	  prototypes for OSF/1-specific routines
- *
- *
- * Portions Copyright (c) 1996-2013, PostgreSQL Global Development Group
- * Portions Copyright (c) 1994, Regents of the University of California
- *
- * src/backend/port/dynloader/osf.h
- *
- *-------------------------------------------------------------------------
- */
-
-#ifndef PORT_PROTOS_H
-#define PORT_PROTOS_H
-
-#include <dlfcn.h>
-#include "utils/dynamic_loader.h"		/* pgrminclude ignore */
-
-/*
- * Dynamic Loader on Alpha OSF/1.x
- *
- * this dynamic loader uses the system dynamic loading interface for shared
- * libraries (ie. dlopen/dlsym/dlclose). The user must specify a shared
- * library as the file to be dynamically loaded.
- */
-
-/*
- * In some older systems, the RTLD_NOW flag isn't defined and the mode
- * argument to dlopen must always be 1.  The RTLD_GLOBAL flag is wanted
- * if available, but it doesn't exist everywhere.
- * If it doesn't exist, set it to 0 so it has no effect.
- */
-#ifndef RTLD_NOW
-#define RTLD_NOW 1
-#endif
-#ifndef RTLD_GLOBAL
-#define RTLD_GLOBAL 0
-#endif
-
-#define  pg_dlopen(f)	dlopen((f), RTLD_NOW | RTLD_GLOBAL)
-#define  pg_dlsym(h, f) ((PGFunction) dlsym(h, f))
-#define  pg_dlclose(h)	dlclose(h)
-#define  pg_dlerror()	dlerror()
-
-#endif   /* PORT_PROTOS_H */
diff --git a/src/backend/utils/misc/ps_status.c b/src/backend/utils/misc/ps_status.c
index 57aa384..d5343a4 100644
--- a/src/backend/utils/misc/ps_status.c
+++ b/src/backend/utils/misc/ps_status.c
@@ -66,7 +66,7 @@ bool		update_process_title = true;
 #define PS_USE_PS_STRINGS
 #elif (defined(BSD) || defined(__hurd__)) && !defined(__darwin__)
 #define PS_USE_CHANGE_ARGV
-#elif defined(__linux__) || defined(_AIX) || defined(__sgi) || (defined(sun) && !defined(BSD)) || defined(ultrix) || defined(__ksr__) || defined(__osf__) || defined(__svr5__) || defined(__darwin__)
+#elif defined(__linux__) || defined(_AIX) || defined(__sgi) || (defined(sun) && !defined(BSD)) || defined(ultrix) || defined(__ksr__) || defined(__svr5__) || defined(__darwin__)
 #define PS_USE_CLOBBER_ARGV
 #elif defined(WIN32)
 #define PS_USE_WIN32
diff --git a/src/include/port/osf.h b/src/include/port/osf.h
deleted file mode 100644
index d56b35b..0000000
--- a/src/include/port/osf.h
+++ /dev/null
@@ -1,4 +0,0 @@
-/* src/include/port/osf.h */
-
-#define NOFIXADE
-#define DISABLE_XOPEN_NLS
diff --git a/src/include/storage/barrier.h b/src/include/storage/barrier.h
index 16a9a0c..bccd7e9 100644
--- a/src/include/storage/barrier.h
+++ b/src/include/storage/barrier.h
@@ -109,16 +109,6 @@ extern slock_t dummy_spinlock;
 #define pg_memory_barrier()		__asm__ __volatile__ ("sync" : : : "memory")
 #define pg_read_barrier()		__asm__ __volatile__ ("lwsync" : : : "memory")
 #define pg_write_barrier()		__asm__ __volatile__ ("lwsync" : : : "memory")
-#elif defined(__alpha) || defined(__alpha__)	/* Alpha */
-
-/*
- * Unlike all other known architectures, Alpha allows dependent reads to be
- * reordered, but we don't currently find it necessary to provide a conditional
- * read barrier to cover that case.  We might need to add that later.
- */
-#define pg_memory_barrier()		__asm__ __volatile__ ("mb" : : : "memory")
-#define pg_read_barrier()		__asm__ __volatile__ ("rmb" : : : "memory")
-#define pg_write_barrier()		__asm__ __volatile__ ("wmb" : : : "memory")
 #elif defined(__hppa) || defined(__hppa__)		/* HP PA-RISC */
 
 /* HPPA doesn't do either read or write reordering */
diff --git a/src/include/storage/s_lock.h b/src/include/storage/s_lock.h
index 7dcd5d9..e3c0ecb 100644
--- a/src/include/storage/s_lock.h
+++ b/src/include/storage/s_lock.h
@@ -551,52 +551,6 @@ tas(volatile slock_t *lock)
 
 #endif	 /* __vax__ */
 
-#if defined(__alpha) || defined(__alpha__)	/* Alpha */
-/*
- * Correct multi-processor locking methods are explained in section 5.5.3
- * of the Alpha AXP Architecture Handbook, which at this writing can be
- * found at ftp://ftp.netbsd.org/pub/NetBSD/misc/dec-docs/index.html.
- * For gcc we implement the handbook's code directly with inline assembler.
- */
-#define HAS_TEST_AND_SET
-
-typedef unsigned long slock_t;
-
-#define TAS(lock)  tas(lock)
-
-static __inline__ int
-tas(volatile slock_t *lock)
-{
-	register slock_t _res;
-
-	__asm__	__volatile__(
-		"	ldq		$0, %1	\n"
-		"	bne		$0, 2f	\n"
-		"	ldq_l	%0, %1	\n"
-		"	bne		%0, 2f	\n"
-		"	mov		1,  $0	\n"
-		"	stq_c	$0, %1	\n"
-		"	beq		$0, 2f	\n"
-		"	mb				\n"
-		"	br		3f		\n"
-		"2:	mov		1, %0	\n"
-		"3:					\n"
-:		"=&r"(_res), "+m"(*lock)
-:
-:		"memory", "0");
-	return (int) _res;
-}
-
-#define S_UNLOCK(lock)	\
-do \
-{\
-	__asm__ __volatile__ ("	mb \n"); \
-	*((volatile slock_t *) (lock)) = 0; \
-} while (0)
-
-#endif /* __alpha || __alpha__ */
-
-
 #if defined(__mips__) && !defined(__sgi)	/* non-SGI MIPS */
 /* Note: on SGI we use the OS' mutex ABI, see below */
 /* Note: R10000 processors require a separate SYNC */
@@ -735,28 +689,6 @@ tas(volatile slock_t *s_lock)
 
 #endif	 /* defined(USE_UNIVEL_CC) */
 
-
-#if defined(__alpha) || defined(__alpha__)	/* Tru64 Unix Alpha compiler */
-/*
- * The Tru64 compiler doesn't support gcc-style inline asm, but it does
- * have some builtin functions that accomplish much the same results.
- * For simplicity, slock_t is defined as long (ie, quadword) on Alpha
- * regardless of the compiler in use.  LOCK_LONG and UNLOCK_LONG only
- * operate on an int (ie, longword), but that's OK as long as we define
- * S_INIT_LOCK to zero out the whole quadword.
- */
-#define HAS_TEST_AND_SET
-
-typedef unsigned long slock_t;
-
-#include <alpha/builtins.h>
-#define S_INIT_LOCK(lock)  (*(lock) = 0)
-#define TAS(lock)		   (__LOCK_LONG_RETRY((lock), 1) == 0)
-#define S_UNLOCK(lock)	   __UNLOCK_LONG(lock)
-
-#endif	 /* __alpha || __alpha__ */
-
-
 #if defined(__hppa) || defined(__hppa__)	/* HP PA-RISC, GCC and HP compilers */
 /*
  * HP's PA-RISC
diff --git a/src/template/osf b/src/template/osf
deleted file mode 100644
index 4f10ad6..0000000
--- a/src/template/osf
+++ /dev/null
@@ -1,6 +0,0 @@
-# src/template/osf
-
-if test "$GCC" != yes ; then
-  CC="$CC -std"
-  CFLAGS="-O -ieee"
-fi
